<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mutualisation?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// M
	'mutualisation_description' => 'This plugin provides some function that facilitate site’s mutualisation, particularly: <code>demarrer_site()</code>, <code>prefixe_mutualisation()</code> and <code>mutualiser_creer()</code>. Be careful, the installation of this plugin is different than general one (see documentation).',
	'mutualisation_nom' => 'Easy mutualisation',
	'mutualisation_slogan' => 'Build a SPIP farm'
);
